OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

# Informes

Ahora que ha terminado de identificar todos los riesgos en su organización y que ha creado un plan de acción, puede crear un informe con los resultados. Si lo desea, puede agregar algunos comentarios adicionales que deberán incluirse en este informe en el campo de abajo.

Guardar y continuar

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More